summaryrefslogtreecommitdiffstats
path: root/src/main_dpdk.cpp
diff options
context:
space:
mode:
authorYaroslav Brustinov <ybrustin@cisco.com>2016-08-22 22:16:27 +0300
committerYaroslav Brustinov <ybrustin@cisco.com>2016-08-22 22:16:27 +0300
commit2ee9ac46d8cc4de627be868d7cb36ad0a11e898d (patch)
treeae3ef3b084ba75113346411a7947e4fa64f3d46b /src/main_dpdk.cpp
parente939511acbb16cda3dab34fe255160ae7ae19258 (diff)
interactive creation of config, finish returning DPDK interfaces to Linux command.
Diffstat (limited to 'src/main_dpdk.cpp')
-rw-r--r--src/main_dpdk.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/main_dpdk.cpp b/src/main_dpdk.cpp
index f0320921..4b5cedbc 100644
--- a/src/main_dpdk.cpp
+++ b/src/main_dpdk.cpp
@@ -4968,12 +4968,13 @@ void dump_interfaces_info() {
struct rte_pci_addr pci_addr;
for (uint8_t port_id=0; port_id<m_max_ports; port_id++) {
// PCI and MAC
pci_addr = rte_eth_devices[port_id].pci_dev->addr;
rte_eth_macaddr_get(port_id, &mac_addr);
ether_format_addr(mac_str, sizeof mac_str, &mac_addr);
- printf("PCI: %04x:%02x:%02x.%d - MAC: %s\n",
- pci_addr.domain, pci_addr.bus, pci_addr.devid, pci_addr.function, mac_str);
+ printf("PCI: %04x:%02x:%02x.%d - MAC: %s - Driver: %s\n",
+ pci_addr.domain, pci_addr.bus, pci_addr.devid, pci_addr.function, mac_str,
+ rte_eth_devices[port_id].pci_dev->driver->name);
}
}
@@ -4968,12 +4968,13 @@ void dump_interfaces_info() {
struct rte_pci_addr pci_addr;
for (uint8_t port_id=0; port_id<m_max_ports; port_id++) {
- // PCI and MAC
+ // PCI, MAC and Driver
pci_addr = rte_eth_devices[port_id].pci_dev->addr;
rte_eth_macaddr_get(port_id, &mac_addr);